@@ -275,12 +275,12 @@ class YAMLConfig(ABC):
             if params.typecast is not None and value is not None:
                 value = params.typecast(value)
             kwargs[params.kwarg_alias or name] = (type(value), None)
-        # create the model
-        out = create_model(
-            f'{cls.__name__}Model',
-            **kwargs,
-        )
-        schema_extra = out.Config.schema_extra
+
+        class Config:
+            """custom schema configuration"""
+            schema_extra = {}
+
+        schema_extra = Config.schema_extra
         schema_extra['properties'] = {}
         for name, params in cls.yaml_parameters.items():
             value = params.default_value
@@ -290,6 +290,12 @@ class YAMLConfig(ABC):
                 'title': params.kwarg_alias or name,
                 'description': params.docstring + f" (default: {value})",
             }
+        # create the model
+        out = create_model(
+            f'{cls.__name__}Model',
+            **kwargs,
+            __config__=Config,
+        )
         return out
 
     @classmethod
